pub struct ObjectHandle(/* private fields */);Expand description
Identifiers that provide a device- and session-unique consistent reference to a logical object on a device.
Object handles are used in MTP transactions to reference a logical object on the device, but do not necessarily reference actual data constructs on the device.
Object handles are only persistent within an MTP session; once a session has been re-opened, all previous values shall be assumed to be invalid, and the contents of the Responder must be re-enumerated if object handles are needed
Implementations
Sourceimpl ObjectHandle
impl ObjectHandle
Sourcepub const NONE: ObjectHandle
pub const NONE: ObjectHandle
Indicates the absense of an object handle
This is used in both parameters (e.g. not assigning a parent to an object), and return types in contexts where missing objects are not errors.
Sourcepub const ALL: ObjectHandle
pub const ALL: ObjectHandle
Indicates a selection of all objects in the context
For example in the DeleteObject operation, this can be used to delete all objects on the
responder.